slepc-3.18.0 2022-10-01
Report Typos and Errors

# RGSetType

Selects the type for the RG object.

### Synopsis

    #include "slepcrg.h"
    PetscErrorCode RGSetType(RG rg,RGType type)

Logically Collective on rg

### Input Parameters

| rg | - the region context
| type | - a known type

### See Also

RGGetType()

### Level

intermediate

### Location

src/sys/classes/rg/rgbasic.c

### Examples

src/eps/tutorials/ex30.c.html
src/nep/tutorials/ex27.c.html
src/nep/tutorials/ex27f90.F90.html
src/nep/tutorials/ex42.c.html
Index of all RG routines
Table of Contents for all manual pages
Index of all manual pages